@@ -1,10 +1,10 @@
 var HelloWorld;
 
 HelloWorld = (function() {
-  function HelloWorld() {}
+  class HelloWorld {};
 
   HelloWorld.test = 'test';
 
   return HelloWorld;
 
-})();
+}).call(this);
