@@ -2,12 +2,12 @@
   var HelloWorld;
 
   HelloWorld = (function() {
-    function HelloWorld() {}
+    class HelloWorld {};
 
     HelloWorld.test = 'test';
 
     return HelloWorld;
 
-  })();
+  }).call(this);
 
 }).call(this);
