@@ -2,13 +2,13 @@
   var HelloWorld;
 
   HelloWorld = (function() {
-    function HelloWorld() {}
+    class HelloWorld {};
 
     HelloWorld.test = 'test';
 
     return HelloWorld;
 
-  })();
+  }).call(this);
 
   console.log('hi');
 
